bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 33. Aventiure
___________________________________________________ #### Wie die Bvrgonden mit den Hevnen striten
| ### lso der kvene Dancwart vnder div tvr getrat ### daz Eceln gesinde er hoher wichen bat ### mit blvote waz bervnnen allez sin gewant [77a] ### ein vil scharfez wafen trvog er bloz an siner hant
###### 1889 | ### Uil lvte rief do Dancwart zvo dem degne ### ir sitzet alze lange brvoder Hagne ### iv vnd gote von himele klage ich vnser not ### rittere vn– knehte sint an den herbergen tot
###### 1890 | ### Er rief im hin enkegne wer hat daz getan ### daz hat der herre Bloedel vn– sein man ### ovch hat ers sere enkolten daz wil ich iv sagen ### ich han mit minen handen im sin hovpt ab geslagen
###### 1891 | ### Daz ist ein schade kleine sprach do Hagne ### da man sæit mere von eime degne ### ob er von reken handen verlivzet sinen lip ### in svln deste ringer klagen wætlichiv wip
###### 1892 | ### Nv saget mir brvoder Dancwart wie sit ir so tot ### ich wene ir von wunden lidet groze not ### ist er inder inme lande der ez iv hat getan ### in erner der vbel tivel ez mvoz im an sin leben gan
###### 1893 | ### Ir sehet mich wol gesvnden min wat ist blvotez naz ### von ander manne wunden ist mir geschehen daz ### der ich also manigen hivte han erslagen ### ob ich des swern solde ich kvndez nimmer gesagen
###### 1894 | ### Er sprach brvoder Dancwart so hvetet vns der tvr ### lat der Hvnen einen komen niht derfvr ### ich wil reden mit den reken als vns des twinget not ### vnser ingesinde lit vor in vnverdienet tot
###### 1895 | ### Sol ich sin kamerere sprach der kvene man ### also richen kvnigen ich wol gedienen chan ### so phlige ich der stiegen nah den eren min ### den Kriemhilde degnen kvnde leider niht gesein
###### 1896 | ### Mich nimet des michel wunder sprach aber Hagne ### waz nv hie inne rvnen die Hvnen degne ### si wene dez lihte enbern der an tvr da stat ### vn– div hovemere geseit den Bvrgonden hat
###### 1897 | ### Ich han vernomen lange von Kriemhilde sagen ### daz si ir herzeleide wolde niht vertragen ### nv trinken wir die minne vn– gelten des kvniges wein ### Der ivnge voit der Hvnen der mvoz der aller erste sin
###### 1898 | ### Do slvoch daz kint Ortlieben Hagne der helt gvot ### daz im gein der hende anme swerte vloz daz blvot ### vn– der kvniginne daz hovpt spranch in die schoz ### do hvop sich vnder den degnen ein mort vil grimme vn– groz
###### 1899 | ### Er slvoch dem meitzogen einen swinden swertes slach ### mit beiden sinen henden der des kindes phlach ### daz im daz hovbet schiere vor tische nider lach ### ez was ein iemerlich lon den er dem maitzogen wach
###### 1900 | ### Er sach vor Eceln tische einen spilman ### Hagne in sime zorne gahen dar began ### er slvog im vf der gigen abe die zeswen hant ### daz habe dir ze botschefte in der Bvrgonden lant [77b]
###### 1901 | ### So we mir miner sprach Wærbel san ### her Hagne von Trony waz han ich <iv> getan ### ich kom vf groze triwe in iwer herren lant ### wie klenk ich nv die doene sid ich verlorn han die hant
###### 1902 | ### Hagne ahte ringe gevidelte er nimmer mer ### do vrvmte er inme hvse div werchgrimme ser ### an den Eceln reken der er so vil erslvoch ### do brahte er in dem hvse der reken ze tode genvoch
###### 1903 | ### Uolker der vil snelle von dem tische spranch ### sin videlboge im lvte an siner hant erklanch ### do videlte vngefvoge Gvnthers spilman ### hey waz er im ze viende der kvenen Hvnen gewan
###### 1904 | ### <ovch> sprungen von dem tischen die dri kunige here ### si woldenz gerne scheiden e schade geschæhe mer ### si mochtenz mit ir sinnen do niht vnderstan ### do Volker vn– Hagne so sere wueten began
###### 1905 | ### Do sach der voit von Rine vngescheiden den strit ### do slvoch der fvrste selbe manige wunden wit ### dvrh die liehten ringe den vienden sin ### er waz ein helt zen handen daz tet er groezlichen schin
###### 1906 | ### Do kom ovch zvo dem strite der starche Gernot ### ia vrvmte er der Hvnen vil manigen helt tot ### mit eime scharfen swerte daz im gap Rvedeger ### den Eceln reken tet er div gremlichen ser
###### 1907 | ### Der ivnge svn vrovn voten zvo dem strite spranch ### sin wafen herlichen dvrch die helme ranch ### den Eceln reken vz der Hvnen lant ### da tet vil michel wunder des kvenen Gyselhers hant
###### 1908 | ### Swie vrvm si alle warn die kvnige vn– ovch ir man ### do sach man vor in allen Gyselhern stan ### gein den vienden ez ist ein helt gvot ### er vrumte mit willen manigen vallen in daz blvot
###### 1909 | ### oech werten sich vil sere die Eceln man ### do sach man och die geste howende gan ### mit den vil liehten swerten dvrh des kvniges sal ### man horte allenthalben von woffe grozzlichen schal
###### 1910 | ### Do wolden die dar vze zvo ir vrivnden sin dar in ### die namen an den tvrn vil kleinen gewin ### do wern die dar inne vil gerne fvr den sal ### Dancwart liez ir deheinen die stiegen vf noch zetal
###### 1911 | ### Des hvop sich vor den tvrn vil starcher gedranch ### vn– ovch von den swerten grozer helm klanch ### des kom der kvene Dancwart in eine groze not ### da besorgte sin brvoder als im sin triwe gebot
###### 1912 | ### Uil lvte rief do Hagne Volkern an ### sehet ir dort geselle minen brvoder stan ### vor hunelichsen reken vnder starken slegen ### vrivnt nert mir den brvoder wir verliesen den degen
###### 1913 | ### Daz tvon ich sicherlichen sprach der spilman [78a] ### er begvnde videlnde dvrch den palas gan ### ein hertez swert im ofte an siner hant erkanch ### die reken von Rine im seiten grozlichen danch
###### 1914 | ### Volker der kvene zvo Dancwarte sprach ### ir habet erliten hivte vil grozen vngemach ### mich bat iwer brvoder dvrch helfe zvo iv gan ### welt ir nv sin dar vze so wil ich innerthalben stan
###### 1915 | ### Dancwart der snelle stvont vzerhalp der tvre ### er werte in ir stiege swaz ir kom da fvre ### des horte man waffen hellen den helden an der hant ### sam tet ovch innerthalp Volker von Bvrgonden lant
###### 1916 | ### Der kvene videlere rief vber die menige ### der sal ist wol beslozen vriunt her Hagne ### ia ist also verschrenchet div Ecelen tvre ### von zweier helde handen da gent wol tvsent rigele fvr
###### 1917 | ### Do von Trony Hagne div tur sach so behvot ### den schilt warf do ze rvcke der mære helt gvot ### alrest begvnd er reken daz im da waz getan ### do heten sine viende ze lebne deheiner slahte wan
###### 1918 | ### Do der voit von Rine rehte daz ersach ### daz Hagne der starche so manigen helm brach ### ein kvnich von Amelvnge spranch vf eine banch ### er sprach hie schenket Hagne daz aller wirste tranch
###### 1919 | ### Der wirt hete groze sorge als im daz gezam ### waz man im lieber vriunde vor sinen ovgen nam ### wan er vor sinen vienden vil kvme da genas ### er saz vil angestlich waz half in daz er kvnic waz
###### 1920 | ### Kriemhilt div riche rief Dietrichen an ### hilf mir ritter edel mit dem libe dan ### dvrh aller fvrsten tvgent vz Amelvnge lant ### wan erreichet mich Hagne ich han den tot an der hant
###### 1921 | ### Wie sol ich iv gehelfen sprach her Dietrich ### edel kvniginne nv sorge ich vmbe mich ### ez sint so ser erzvrnet Gvntheres man ### daz ich an disen ziten niemen gevriden kan
###### 1922 | ### Neina her Dietrich edel ritter gvot ### laza hivte schowen dinen tvgentlichen mvot ### daz dv mir helfest hinnen oder ich belibe tot ### mich twinget iamers sorge ez gat mir an des libes not
###### 1923 | ### Daz wil ich versvochen ob ich iv gehelfen kan ### wan ich in langen ziten nie gesehen han ### so bitterlich erzvrnet manigen ritter gvot ### ia sihe ich dvrh die helme von swerten springen daz blvot
###### 1924 | ### Mit kraft begvnde rvefen der ritter vz erkorn ### daz sin stimme erlute alsam ein wisntes horn ### vn– daz div bvrch vil wite von siner kraft erdoz ### div sterke Dietriches was <vnmazichen> groz
###### 1925 | ### Do gehorte rvefen Gvnther disen man ### in dem vil herten sturme losen er began [78b] ### er sprach Dietriches stimme ist in min ore komen ### ich wen im vnser degne haben etwen benomen
###### 1926 | ### Ich sich in vf dem tische winken mit der hant ### vrivnt vn– mage von Bvrgonden lant ### habet vf des strites lat hoern vnd sehen ### waz hie dem degne von minen mannen si geschehen
###### 1927 | ### Do der kvnich Gvnther bat vnd ovch gebot ### si habten vf mit swerten in des strites not ### daz was gewalt vil grozer daz da niemen slvoch ### er vragte den von Berne der mere schiere genvoch
###### 1928 | ### Er sprach vil edel Dietrich waz ist iv hie getan ### von minen vriunden willen ich des han ### bvoze vn– svone der bin ich iv bereit ### swaz iv iemen tete daz wer mir innerclichen leit
###### 1929 | ### Do sprach der herre Dietrich mir ist niht getan ### lat mich vz dem hvse mit ivrme vride gan ### von disem hertem strite mit dem gesinde min ### daz wil ich sicherlichen immer dienende sin
###### 1930 | ### Wie vilehet ir so schiere sprach der Wolfhart ### ia hat der videlere die tur nie so verspart ### wir entsliezen si so wite daz wir dar fvr gan ### nv swie sprach her Dietrich dv hast den tievel getan
###### 1931 | ### Do sprach der kvnich Gvnther erlovben ich iv wil ### fvert vz dem hvse wenich oder vil ### an mine viende die svln hie bestan ### si hant mir zen Hvnen so rehte leide getan
###### 1932 | ### Do er daz erhorte vnder arm er besloz ### die edeln kvniginne ir sorge waz vil groz ### do fvort er anderthalben Eceln mit im dan ### ovch gie mit Dietriche vil manich wetlicher man
###### 1933 | ### Do sprach der edel marcrave Rvedeger ### sol aber vz dem hvse iemen komen mer ### die iv doch gerne dienent daz lat vns vernemen ### so sol vride stete gvoten vriunden zemen
###### 1934 | ### Dez antwurte Gyselher von Bvrgonden lant ### vride vn– svone si iv von vns bekant ### sit ir sit triwen stete ir vn– iwer man ### ir svlt vnangestlichen mit vren vrivnden hinnen gen
###### 1935 | ### Do der herre Rvedeger gervmte den sal ### fvnf hvndert oder mere im volgten vber al ### daz was von herren dvrch triwe getan ### da von der kvnich Gvnther sit grozen schaden getan
###### 1936 | ### Do sach ein Hvnen reke Eceln gan ### bi Dietriche nahen genozzen wold ers han ### dem gap der videlere einen soelhen slach ### daz im daz hovbet schiere vor Eceln fvezen gelach
###### 1937 | ### Do der wirt des landes kom fvr daz hvs gegan ### do kerte er sich hin wider vn– sach Volkern an ### owe mir dirre geste ditz ist ein grimme not [79a] ### daz alle mine reken vor in svln ligen tot
###### 1938 | ### Ach we der hohzite sprach der kvnich her ### da vihtet einer inne der heizet Volker ### alsam ein eber wilde vn– ist ein spilman ### ich dankes mime heile daz ich dem tievel entran
###### 1939 | ### Sin leiche lvtent vbel sin zvge sint rot ### ia wellent sine doene manigen helt tot ### ich weiz niht waz vns wiset der selbe spilman ### wan ich gast nie einen so rehte leiden gewan
###### 1940 | ### Si heten die si wolden lazen fvr den sal ### do hvop sich innerhalben grozlicher schal ### die geste sere rachen daz in e geschach ### Volker der vil kvene hey waz er helme zebrach
###### 1941 | ### Sich kerte gein dem schalle Gvnther der kvnich her ### hoert ir die doene Hagne die dort Volker ### videlt mit den Hvnen swer zvo den tvrn gat ### ez ist ein roter anstrich den er zem videlbogen hat
###### 1942 | ### Mich riwet ane maze so sprach Hagne ### daz ich ie gesaz in dem hvse vor dem degne ### ich waz sin geselle vn– ovch er der min ### kom wir immer wider heim daz svl wir noh mit triwen sin
###### 1943 | ### Nv schowe kvnich her Volker ist dir holt ### er dient willeclichen din silber vn– din golt ### sin videlboge snidet dvrch den herten stal ### er brichet vf den helmen div lieht schinenden mal
###### 1944 | ### In gesach nie videlere so herlich stan ### also der degen Volker hivte hat getan ### sin leiche hellent dvrch helm vn– dvrch rant ### ia sol er riten gvotiv ros vn– tragen herlich gewant
###### 1945 | ### Swaz der Hvnen mage in dem sale was gewesen ### der waz nv deheiner dar inne me genesen ### des waz der schal geswiftet daz niemen mit in streit ### div swert von handen leiten die kvenen reken gemit

<<< Übersicht <<< vorige Seite nächste Seite >>>